@@ -3,6 +3,9 @@
 #' Realise outcomes for all causal types. Calculated by sequentially calculating endogenous nodes.
 #' If a do operator is applied to any node then it takes the given value and all its descendants are generated accordingly.
 #'
+#' If a node is not specified all outcomes are realised for all possible causal types consistent with the model.
+#' If a node is specified then outcomes of Y are returned conditional on different values of parents, whether or not these values of the parents obtain given restrictions under the model.
+#'
 #' @details \code{realise_outcomes} starts off by creating types (via \code{\link{get_nodal_types}}). It then takes types of endogenous and reveals their outcome based on the value that their parents took. Exogenous nodes outcomes correspond to their type.
 #' @inheritParams CausalQueries_internal_inherit_params
 #' @param dos A named \code{list}. Do actions defining node values, e.g., \code{list(X = 0, M = 1)}.
@@ -15,13 +18,17 @@
 #' make_model("X -> Y") |>
 #'   realise_outcomes()
 #'
-#'make_model("X -> Y <- W") |>
+#' make_model("X -> Y <- W") |>
 #' set_restrictions(labels = list(X = "1", Y="0010"), keep = TRUE) |>
 #'  realise_outcomes()
 #'
 #' make_model("X1->Y; X2->M; M->Y") |>
 #' realise_outcomes(dos = list(X1 = 1, M = 0))
 #'
+#' # With node specified
+#' make_model("X->M->Y") |>
+#' realise_outcomes(node = "Y")
+#'
 #' make_model("X->M->Y") |>
 #' realise_outcomes(dos = list(M = 1), node = "Y")
 #'}
@@ -29,27 +36,13 @@
 realise_outcomes <- function(model, dos = NULL, node = NULL, add_rownames = TRUE){
 
   # check dos + node specification
-  if(!is.null(node)) {
-
-    if(length(node) > 1) {
-      stop("Please specify only one node")
-    }
-
-    if(is.null(dos)) {
-      stop("Do actions must be specified when node is not NULL")
-    }
-
-    if(!all(get_parents(model)[[node]] %in% names(dos))) {
-      stop("Please specify givens for all parents of the node you specified")
-    }
-
+  if((!is.null(node)) && (length(node) > 1)) {
+    stop("Please specify only one node")
   }
 
-  # get causal types
-  data_realizations <- get_causal_types(model)
-
   # case with trivial single node model
   if(length(model$nodes) == 1) {
+    data_realizations <- get_causal_types(model)
     if (add_rownames) {
       rownames(data_realizations) <-
         gsub("[[:alpha:]]", "", rownames(data_realizations))
@@ -57,14 +50,13 @@ realise_outcomes <- function(model, dos = NULL, node = NULL, add_rownames = TRUE
     return(data_realizations)
   }
 
-
   # case with node specified
   if(!is.null(node)) {
     # generate data realizations
     parents <- get_parents(model)[[node]]
 
     if(any(!names(dos) %in% parents)) {
-      conjugation <- ifelse (sum(!names(dos) %in% parents)>1, "are not parents of", "is not a parent of")
+      conjugation <- ifelse (sum(!names(dos) %in% parents)>1, "are not a parent of", "is not a parent of")
       subjects <- paste0(names(dos)[!names(dos) %in% parents], collapse = ", ")
       if(all(!names(dos) %in% parents)){
         stop(paste(subjects, conjugation, node))
@@ -73,27 +65,35 @@ realise_outcomes <- function(model, dos = NULL, node = NULL, add_rownames = TRUE
       }
     }
 
-    nodal_types <- get_nodal_types(model)[[node]]
-    data_realizations <- data.frame(sapply(parents, function(p) as.character(rep(dos[p], length(nodal_types)))),
-                                    nodal_types,
-                                    stringsAsFactors = FALSE)
-    colnames <- c(parents, node)
-    names(data_realizations) <- colnames
+    nodes <- c(parents, node)
+    nodal_types <- get_nodal_types(model)[nodes]
 
-    # replace parent names with parent col positions in data_realizations df
-    # allows for faster access when df is converted to std::vector<std::vector<std::string>> in c++
-    parents_list <- as.list(rep(-1,length(parents)))
-    parents_list <- c(parents_list, list((1:length(parents)) - 1))
-    names(parents_list) <- c(parents,node)
+    # treat parents as exogenous and add dos
+    for(p in parents) {
+      if(p %in% names(dos)) {
+        nodal_types[[p]] <- as.character(dos[[p]])
+      } else {
+        nodal_types[[p]] <- c("0","1")
+      }
+    }
 
-    # get variables to work through
-    endogenous_vars <- which(colnames(data_realizations) == node) - 1
+    data_realizations <- expand.grid(nodal_types, stringsAsFactors = FALSE)
+    colnames <- nodes
+    names(data_realizations) <- nodes
 
     # rownames
-    if(add_rownames){
-      types <- data_realizations[,endogenous_vars + 1, drop = FALSE]
+    if(add_rownames) {
+      types <- data_realizations
     }
 
+    # generate parents_list
+    parents_list <- as.list(rep(-1,length(parents)))
+    parents_list <- c(parents_list, list((1:length(parents)) - 1))
+    names(parents_list) <- nodes
+
+    # get variables to work through
+    endogenous_vars <- length(nodes) - 1
+
     # turn data_realizations df into list to pass as std::vector<std::vector<std::string>>
     n_types <- nrow(data_realizations)
     data_realizations <- as.list(data_realizations)
@@ -102,18 +102,11 @@ realise_outcomes <- function(model, dos = NULL, node = NULL, add_rownames = TRUE
 
   # case without node specified
   if(is.null(node)) {
+    # get data realizations
+    data_realizations <- get_causal_types(model)
     # replace parent names with parent col positions in data_realizations df
     # allows for faster access when df is converted to std::vector<std::vector<std::string>> in c++
-    parents_list  <- get_parents(model) |>
-      lapply(function(i) {
-        if (length(i) > 0) {
-          sapply(i, function(j)
-            which(j == model$nodes)) |>
-            unname() - 1
-        } else {
-          -1
-        }
-      })
+    parents_list  <- parents_to_int(get_parents(model), model$nodes)
 
     # rownames
     if(add_rownames) {
@@ -148,19 +141,35 @@ realise_outcomes <- function(model, dos = NULL, node = NULL, add_rownames = TRUE
 
   # add rownames
   if(add_rownames){
-    if(!is.null(node)) {
-      attr(data_realizations, "type_names") <- rownames(data_realizations) <- apply(types, 1, FUN = function(x) paste0(x))
-    } else {
-      rownames(data_realizations) <- apply(types, 1, paste, collapse = ".")
-      type_names <- matrix(sapply(1:ncol(types), function(j) paste0(names(types)[j], types[,j])), ncol = ncol(types))
-      attr(data_realizations, "type_names") <- apply(type_names, 1, paste,  collapse = ".")
-    }
+    rownames(data_realizations) <- apply(types, 1, paste, collapse = ".")
+    type_names <- matrix(sapply(1:ncol(types), function(j) paste0(names(types)[j], types[,j])), ncol = ncol(types))
+    attr(data_realizations, "type_names") <- apply(type_names, 1, paste,  collapse = ".")
   }
 
   return(data_realizations)
 }
 
 
+#' Helper to turn parents_list into a list of data_realizations column positions
+#' @param parents_list a named list of character vectors specifying all nodes in the DAG and their respective parents
+#' @return a list of column positions
+#' @keywords internal
+#' Used in realise_outcomes
+
+parents_to_int <- function(parents_list, position_set) {
+  out <- parents_list |>
+    lapply(function(i) {
+      if (length(i) > 0) {
+        sapply(i, function(j)
+          which(j == position_set)) |>
+          unname() - 1
+      } else {
+        -1
+      }
+    })
+
+  return(out)
+}
 
 
 #' Reveal outcomes
@@ -178,7 +187,9 @@ reveal_outcomes <- function(model, dos = NULL, node = NULL) {
   details = "This function was deprecated because the name causes clashes with DeclareDesign. Use realise_outcomes instead."
 )
   warning("This function was deprecated because the name causes clashes with DeclareDesign. Use realise_outcomes instead.")
-realise_outcomes(model = model, dos = dos, node = node)
+  realise_outcomes(model = model, dos = dos, node = node)
 }
 
 
+
+
