@@ -1,12 +1,15 @@
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
 
-if (.runThisTest) {
+
+
 
 context("Testing get_nodal_types")
 
+testthat::skip_on_cran()
 testthat::test_that(
+
 	desc = "Condition for make_nodal_types",
+
 	code = {
 		out_true <- CausalQueries:::make_nodal_types(make_model("X -> Y"), include_node_names = TRUE)
 		expect_true(all(grepl("X", rownames(out_true$X))))
@@ -16,7 +19,9 @@ testthat::test_that(
 )
 
 testthat::test_that(
+
 	desc = "Testing collapse_nodal_types",
+
 	code = {
 		model <- make_model("X -> Y")
 		expect_equal(model$nodal_types, CausalQueries:::collapse_nodal_types(model$nodal_types))
@@ -34,4 +39,4 @@ testthat::test_that(
 	}
 )
 
-}
+
